@@ -3,7 +3,9 @@ package Mail::Postfix::Attr;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+use Carp ;
+
+our $VERSION = '0.03';
 
 my %codecs = (
 
@@ -21,6 +23,7 @@ sub new {
 	my $codec_ref = $codecs{ $args{'codec'} } || $codecs{ 'plain' } ;
 
 	$self->{'sock_path'} = $args{'path'} ;
+	$self->{'inet'} = $args{'inet'} ;
 
 	( $self->{'encode'}, $self->{'decode'} ) = @{$codec_ref} ;
 
@@ -31,20 +34,39 @@ sub send {
 
 	my ( $self ) = shift ;
 
-	require IO::Socket::UNIX ;
+	my $handle ;
 
-	my $sock = IO::Socket::UNIX->new( $self->{'sock_path'} ) ;
+	if ( $self->{'sock_path'} ) {
 
-	$sock or die
+		require IO::Socket::UNIX ;
+
+		$handle = IO::Socket::UNIX->new( $self->{'sock_path'} ) ;
+
+		$handle or croak
 "Mail::Postfix::Attr can't connect to '$self->{'sock_path'}' $!\n" ;
+	}
+	elsif ( $self->{'inet'} ) {
+
+		require IO::Socket::INET ;
+
+		$handle = IO::Socket::INET->new( $self->{'inet'} ) ;
+
+		$handle or croak
+"Mail::Postfix::Attr can't connect to '$self->{'inet'}' $!\n" ;
+
+	}
+	else {
+		croak "must have 'path' or 'inet' set to use send" ;
+	}
 
 	my $attr_text = $self->encode( @_ ) ;
 
-	syswrite( $sock, $attr_text ) ;
+	my $cnt = syswrite( $handle, $attr_text ) ;
 
-	my $attr_buf ;
+#print "ERR $!\n" unless defined $cnt ;
+#print "sent $cnt [$attr_text]\n" ;
 
-	sysread( $sock, $attr_buf, 64000 ) ;
+	sysread( $handle, my $attr_buf, 64000 ) ;
 
 #print "SEND READ [$attr_buf]\n" ;
 
@@ -170,6 +192,10 @@ Mail::Postfix::Attr - Encode and decode Postfix attributes
   my $pf_attr = Mail::Postfix::Attr->new( 'codec' => '0',
 					  'path' => '/tmp/postfix_sock' ) ;
 
+
+  my $pf_attr = Mail::Postfix::Attr->new( 'codec' => 'plain',
+					  'inet' => 'localhost:9999' ) ;
+
   my @result_attrs = $pf_attr->send( 'foo' => 4, 'bar' => 'blah' ) ;
 
   my $attr_text = $pf_attr->encode( 'foo' => 4, 'bar' => 'blah' ) ;
@@ -216,22 +242,31 @@ The new method takes a list of key/value arguments.
 
 	codec	=> <codec_type>
 	path	=> <unix_socket_path>
+	inet	=> <host:port>
 
 	codec_type is one of '0', '64' or 'plain'. It defaults to
 	'plain' if not set or it is not in the allowed codec set.
 
-	The <unix_socket_path> is the unix domain socket that will be
-	used to send a message to a postfix service. The message will
-	be encoded and its response decoded with the selected codec.
+	The <unix_socket_path> argument is the unix domain socket that
+	will be used to send a message to a postfix service. The
+	message will be encoded and its response decoded with the
+	selected codec.
+
+	The <inet> argument is the internet domain address that will
+	be used to send a message to a postfix service. It must be in
+	the form of "host:port" where host can be a hostname or IP
+	address and port can be a number or a name in
+	/etc/services. The message will be encoded and its response
+	decoded with the selected codec.
 
 =head2 send() method 
 
 The send method is passed a list of postfix attribute key/value
-pairs. It first connects to a postfix service using a UNIX domain
-socket and the C<path> for that socket. It then encodes the attributes
-using the selected codec and writes that data to the socket. It then
-reads from the socket to EOF and decodes that data with the codec and
-returns that list of attribute key/value pairs to the caller.
+pairs. It first connects to a postfix service using the UNIX or INET
+socket. It then encodes the attributes using the selected codec and
+writes that data to the socket. It then reads from the socket to EOF
+and decodes that data with the codec and returns that list of
+attribute key/value pairs to the caller.
 
   my @result_attrs = $pf_attr->send( 'foo' => 4, 'bar' => 'blah' ) ;
 
